Package: comtradr
Title: Interface with the United Nations Comtrade API
Version: 1.0.6
Maintainer: Paul Bochtler <paulbochtler.gh@gmail.com>
Authors@R: c(
            person("Paul", "Bochtler", 
              email = "paulbochtler.gh@gmail.com", 
              role = c("aut", "cre","cph"),
              comment = c(ORCID = "0000-0002-9146-6185")), 
            person("Harriet", "Goers", 
              email = "hgoers@umd.edu", 
              role = c("aut")), 
            person("Chris", "Muir", 
              email = "chrismuirRVA@gmail.com", 
              role = c("aut")), 
            person("Alicia", "Schep", 
                  role = "rev", 
                  comment = c(ORCID = "0000-0002-3915-0618", 
                              "Alicia reviewed the package for rOpenSci, 
                  see https://github.com/ropensci/onboarding/issues/141")), 
            person("Rafael", "Hellwig", 
                  role = "rev", 
                  comment = c(ORCID = "0000-0002-3092-3493", 
                              "Rafael reviewed the package for rOpenSci, 
                  see https://github.com/ropensci/onboarding/issues/141")),
            person("Ernest", "Guevarra", 
                  role = "rev", 
                  comment = c(ORCID = "0000-0002-4887-4415", 
                              "Ernest reviewed the package for rOpenSci, 
                  see https://github.com/ropensci/software-review/issues/613")),
            person("Nicholas", "Potter", 
                  role = "rev", 
                  comment = c(ORCID = "0000-0002-3410-3732", 
                              "Nicholas reviewed the package for rOpenSci, 
                  see https://github.com/ropensci/software-review/issues/613")),
            person("Juergen", "Amann", role=c("ctb")))
Description: Interface with and extract data from the United Nations 'Comtrade' 
  API <https://comtradeplus.un.org/>. 'Comtrade' provides country level shipping 
  data for a variety of commodities, these functions allow for easy API query 
  and data returned as a tidy data frame.
Depends: R (>= 4.1.0)
Imports: lifecycle, fs, readr, askpass, cli, httr2, rlang, stringr,
        dplyr, lubridate, purrr, tools, rappdirs, memoise, cachem
Suggests: covr, ggplot2, httptest2, knitr, rmarkdown, spelling,
        testthat (>= 3.0.0), callr
License: GPL-3
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.3
URL: https://docs.ropensci.org/comtradr/,
        https://github.com/ropensci/comtradr
BugReports: https://github.com/ropensci/comtradr/issues
NeedsCompilation: no
VignetteBuilder: knitr
Config/testthat/edition: 3
Language: en-US
Packaged: 2026-07-30 22:46:02 UTC; paulbochtler
Author: Paul Bochtler [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0002-9146-6185>),
  Harriet Goers [aut],
  Chris Muir [aut],
  Alicia Schep [rev] (ORCID: <https://orcid.org/0000-0002-3915-0618>,
    Alicia reviewed the package for rOpenSci, see
    https://github.com/ropensci/onboarding/issues/141),
  Rafael Hellwig [rev] (ORCID: <https://orcid.org/0000-0002-3092-3493>,
    Rafael reviewed the package for rOpenSci, see
    https://github.com/ropensci/onboarding/issues/141),
  Ernest Guevarra [rev] (ORCID: <https://orcid.org/0000-0002-4887-4415>,
    Ernest reviewed the package for rOpenSci, see
    https://github.com/ropensci/software-review/issues/613),
  Nicholas Potter [rev] (ORCID: <https://orcid.org/0000-0002-3410-3732>,
    Nicholas reviewed the package for rOpenSci, see
    https://github.com/ropensci/software-review/issues/613),
  Juergen Amann [ctb]
Repository: CRAN
Date/Publication: 2026-07-30 23:10:02 UTC
Built: R 4.6.1; ; 2026-07-30 23:18:53 UTC; unix
